video2gif ~ vgif
============================

Programmatically generate animated GIF from video in Python

With this video2gif converter you can upload any format of video and rich media files to turn them into high quality animated GIFs.

Getting Started
------------------------------

1. Install
------------------------------

* pip Install
   ``pip install vgif -U``
* source Install
   1. Clone this repository
   2. Run setup from the repository root directory
        ``python3 setup.py install``

2. Start UP
------------------------------

🅶 GUI
------------------------------

.. image:: https://github.com/Haoke98/video2gif/raw/master/assets/interface.png
        :width: 600px
